<!DOCTYPE html>
<html>
    <head>
        <meta charset="UTF-8">
        <title>{{ title }}</title>
        <link href="/nprompter.css" rel="stylesheet" />
    </head>
    <body>
        <div id="help"></div>
        <div id="content">
            {% for element in elements %}{{ element|safe }}
            {% endfor %}
        </div>
        <script src="/script.js"></script>
    </body>
</html>
