@import url('https://fonts.googleapis.com/css2?family=Roboto&display=swap');

body {
    background-color: black;
    color: white;
    scroll-behavior: smooth;
}

#content {
    font-size: 50px;
    padding: 100px 50px;
    font-family: 'Roboto', sans-serif;
}
h1, h2, h3, h4, h5 {
    margin: 10px 0px;
}

p {
    margin: 0px 5px;
}

#help {
  background-color: black;
  font-size: 20px;
  display: block;
  font-family: 'Lato', sans-serif;
  position: fixed;
  top:0; left:0;
  width: 100%;
}

.mirrored {
    -moz-transform: scale(-1, 1);
    -webkit-transform: scale(-1, 1);
    -o-transform: scale(-1, 1);
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1);
}

kbd {
	margin: 0px 0.1em;
	padding: 0.1em 0.6em;
	border-radius: 3px;
	border: 1px solid rgb(204, 204, 204);
	color: rgb(51, 51, 51);
	line-height: 1.4;
	font-family: Arial,Helvetica,sans-serif;
	font-size: 10px;
	display: inline-block;
	box-shadow: 0px 1px 0px rgba(0,0,0,0.2), inset 0px 0px 0px 2px #ffffff;
	background-color: rgb(247, 247, 247);
	-moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.2), 0 0 0 2px #ffffff inset;
	-webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.2), 0 0 0 2px #ffffff inset;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	text-shadow: 0 1px 0 #fff;
}
